@@ -1,4 +1,4 @@
-/*	$NetBSD: msiiep.c,v 1.48 2019/12/30 22:13:47 ad Exp $ */
+/*	$NetBSD: msiiep.c,v 1.49 2020/11/22 03:55:33 thorpej Exp $ */
 
 /*
  * Copyright (c) 2001 Valeriy E. Ushakov
@@ -27,10 +27,10 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: msiiep.c,v 1.48 2019/12/30 22:13:47 ad Exp $");
+__KERNEL_RCSID(0, "$NetBSD: msiiep.c,v 1.49 2020/11/22 03:55:33 thorpej Exp $");
 
 #include <sys/param.h>
-#include <sys/malloc.h>
+#include <sys/kmem.h>
 #include <sys/kernel.h>
 #include <sys/systm.h>
 #include <sys/device.h>
@@ -559,7 +559,7 @@ mspcic_intr_establish(bus_space_tag_t t, int line, int ipl,
 	struct intrhand *ih;
 	int pil;
 
-	ih = malloc(sizeof(struct intrhand), M_DEVBUF, M_WAITOK);
+	ih = kmem_alloc(sizeof(*ih), KM_SLEEP);
 
 	/* use pil set-up by prom */
 	pil = mspcic_assigned_interrupt(line);
