@@ -47,6 +47,7 @@ __KERNEL_RCSID(0, "$NetBSD: ofdisk.c,v 1.54 2020/01/26 21:43:52 thorpej Exp $");
 #include <sys/proc.h>
 
 #include <dev/ofw/openfirm.h>
+#include <machine/promlib.h>
 
 #include <sparc64/dev/vbusvar.h>
 
@@ -137,6 +138,12 @@ static void
 vofdisk_attach(device_t parent, device_t self, void *aux)
 {
 	struct vofdisk_softc *vofd = device_private(self);
+	struct vbus_attach_args *vba = aux;
+
+	vofd->sc_phandle = vba->va_node;
+	printf("vofdisk_attach() sc_phandle %d\n", vofd->sc_phandle);
+	vofd->sc_ihandle = 0;
+	
 #if 0	
 	struct ofbus_attach_args *oba = aux;
 	char child[64];
@@ -199,8 +206,9 @@ vofdisk_open(dev_t dev, int flags, int fmt, struct lwp *lwp)
 			error = ENXIO;
 			goto bad1;
 		}
+		printf("l = %d\n", l);
 		path[l] = 0;
-
+#if 0
 		/*
 		 * XXX This is for the benefit of SCSI/IDE disks that don't
 		 * XXX have all their childs in the device tree.
@@ -215,12 +223,27 @@ vofdisk_open(dev_t dev, int flags, int fmt, struct lwp *lwp)
 		}
 
 		strlcat(path, ":0", sizeof(path));
-
+#else
+#if 1
+		strlcat(path, ":c", sizeof(path));
+#endif		
+#endif
+		printf("vofdisk_open() path [%s]\n", path);
+#if 1
 		if ((of->sc_ihandle = OF_open(path)) == -1) {
 			error = ENXIO;
 			goto bad1;
 		}
+#else		
+		if ((of->sc_ihandle = OF_call_method_1("open", of->sc_ihandle, 1, path)) == -1) {
+			error = ENXIO;
+			printf("vofdisk_open() OF_call_method_1() failed\n");
+			goto bad1;
+		} else {
+		  printf("vofdisk_open() sc_ihandle %d\n", of->sc_ihandle);
+		}
 
+#endif		
 		/*
 		 * Try to get characteristics of the disk.
 		 */
@@ -253,6 +276,7 @@ vofdisk_open(dev_t dev, int flags, int fmt, struct lwp *lwp)
 int
 vofdisk_close(dev_t dev, int flags, int fmt, struct lwp *l)
 {
+  printf("vofdisk_close()\n");
 	struct vofdisk_softc *of =
 		device_lookup_private(&vofdisk_cd, DISKUNIT(dev));
 
@@ -275,7 +299,11 @@ vofdisk_close(dev_t dev, int flags, int fmt, struct lwp *l)
 	OF_seek(of->sc_ihandle, 0);
 #endif
 	if (!of->sc_dk.dk_openmask) {
+#if 0	  
 		OF_close(of->sc_ihandle);
+#else
+		OF_call_method_1("close", of->sc_ihandle, 1, of->sc_ihandle);
+#endif		
 		of->sc_ihandle = 0;
 	}
 
@@ -286,6 +314,7 @@ vofdisk_close(dev_t dev, int flags, int fmt, struct lwp *l)
 void
 vofdisk_strategy(struct buf *bp)
 {
+  printf("vofdisk_strategy() entry\n");
 	struct vofdisk_softc *of =
 		device_lookup_private(&vofdisk_cd, DISKUNIT(bp->b_dev));
 	struct partition *p;
@@ -331,11 +360,13 @@ vofdisk_strategy(struct buf *bp)
 
 done:
 	biodone(bp);
+  printf("vofdisk_strategy() exit\n");
 }
 
 static void
 ofminphys(struct buf *bp)
 {
+  printf("ofminphys()\n");
 	struct vofdisk_softc *of =
 		device_lookup_private(&vofdisk_cd, DISKUNIT(bp->b_dev));
 
@@ -346,18 +377,21 @@ ofminphys(struct buf *bp)
 int
 vofdisk_read(dev_t dev, struct uio *uio, int flags)
 {
+  printf("vofdisk_read()\n");
 	return physio(vofdisk_strategy, NULL, dev, B_READ, ofminphys, uio);
 }
 
 int
 vofdisk_write(dev_t dev, struct uio *uio, int flags)
 {
+  printf("vofdisk_write()\n");
 	return physio(vofdisk_strategy, NULL, dev, B_WRITE, ofminphys, uio);
 }
 
 int
 vofdisk_ioctl(dev_t dev, u_long cmd, void *data, int flag, struct lwp *l)
 {
+  printf("vofdisk_ioctl()\n");
 	struct vofdisk_softc *of =
 		device_lookup_private(&vofdisk_cd, DISKUNIT(dev));
 	int error;
@@ -440,12 +474,14 @@ vofdisk_ioctl(dev_t dev, u_long cmd, void *data, int flag, struct lwp *l)
 int
 vofdisk_dump(dev_t dev, daddr_t blkno, void *va, size_t size)
 {
+  printf("vofdisk_dump()\n");
 	return EINVAL;
 }
 
 int
 vofdisk_size(dev_t dev)
 {
+  printf("vofdisk_size()\n");
 	struct vofdisk_softc *of;
 	struct disklabel *lp;
 	int size, part, omask;
@@ -476,6 +512,7 @@ vofdisk_size(dev_t dev)
 void
 vofdisk_getdefaultlabel(struct vofdisk_softc *of, struct disklabel *lp)
 {
+  printf("vofdisk_getdefaultlabel()\n");
 
 	memset(lp, 0, sizeof *lp);
 
@@ -508,6 +545,7 @@ vofdisk_getdefaultlabel(struct vofdisk_softc *of, struct disklabel *lp)
 void
 vofdisk_getdisklabel(dev_t dev)
 {
+  printf("vofdisk_getdisklabel()\n");
 	int unit = DISKUNIT(dev);
 	struct vofdisk_softc *of =
 		device_lookup_private(&vofdisk_cd, unit);
