@@ -333,8 +333,8 @@ struct {
 #define	ENTER_STAT(x)	do { enter_stats.x ++; } while (0)
 #define	REMOVE_STAT(x)	do { remove_stats.x ++; } while (0)
 
-int	pmapdebug = 0;
-//int	pmapdebug = 0 | PDB_CTX_ALLOC | PDB_ACTIVATE;
+//int	pmapdebug = PDB_BOOT | PDB_BOOT1;
+int	pmapdebug = 0 | PDB_CTX_ALLOC | PDB_ACTIVATE;
 /* Number of H/W pages stolen for page tables */
 int	pmap_pages_stolen = 0;
 
@@ -433,8 +433,10 @@ pseg_set_locksafe(struct pmap *pm, vaddr_t va, int64_t data, paddr_t ptp)
  */
 static void pmap_enter_kpage(vaddr_t va, int64_t data)
 {
+#if 0  
+  printf("pmap_enter_kpage() va %p  data %llx\n", (void*)va, (long long unsigned int)data);
+#endif  
 	paddr_t newp;
-
 	newp = 0UL;
 	while (pseg_set(pmap_kernel(), va, data, newp) & 1) {
 		if (!pmap_get_page(&newp)) {
@@ -1082,24 +1084,38 @@ pmap_bootstrap(u_long kernelstart, u_long kernelend)
 
 	BDPRINTF(PDB_BOOT1, ("Inserting PROM mappings into pmap_kernel()\n"));
 	for (i = 0; i < prom_map_size; i++)
+	{
 		if (prom_map[i].vstart && ((prom_map[i].vstart >> 32) == 0))
+		{
+			printf("i %d   vstart %p\n", i, (void*)prom_map[i].vstart);
 			for (j = 0; j < prom_map[i].vsize; j += PAGE_SIZE) {
+#if 0			  
+				printf("j %d\n", j);
+#endif				
 				int k;
 
 				for (k = 0; page_size_map[k].mask; k++) {
+				  printf("k %d   mask %lx\n", k, page_size_map[k].mask);
 					if (((prom_map[i].vstart |
 					      prom_map[i].tte) &
 					      page_size_map[k].mask) == 0 &&
 					      page_size_map[k].mask <
-					      prom_map[i].vsize)
+					    prom_map[i].vsize) {
+					  printf("break\n");
 						break;
+					}
 				}
 				page_size_map[k].use++;
+#if 0				
+				printf("use %lu\n", page_size_map[k].use);
+#endif				
 				/* Enter PROM map into pmap_kernel() */
 				pmap_enter_kpage(prom_map[i].vstart + j,
 					(prom_map[i].tte + j) | TLB_EXEC |
 					page_size_map[k].code);
 			}
+		}
+	}
 	BDPRINTF(PDB_BOOT1, ("Done inserting PROM mappings into pmap_kernel()\n"));
 
 	/*
