@@ -1131,7 +1131,7 @@ data_access_fault(struct trapframe64 *tf, unsigned int type, vaddr_t pc,
 	vaddr_t onfault;
 	u_quad_t sticks;
 	ksiginfo_t ksi;
-#if 0
+#if 1
 	if (curpcb->pcb_nsaved) {
 	  printf("%ld: data_access_fault(%p, %x, %p, %p, %lx, %lx) "
 		 "nsaved=%d\n",
@@ -1141,7 +1141,7 @@ data_access_fault(struct trapframe64 *tf, unsigned int type, vaddr_t pc,
 #ifdef DEBUG	
 	print_trapframe(tf);
 #endif
-#if 0
+#if 1
 	if (curpcb->pcb_nsaved) {
 	  for (int iii = 0; iii < curpcb->pcb_nsaved+1; iii++) {
 	    printf("data_access_fault() - saved register windows (%d) offset %d", curpcb->pcb_nsaved,
@@ -1163,6 +1163,14 @@ data_access_fault(struct trapframe64 *tf, unsigned int type, vaddr_t pc,
 	  printf("\n");
 	}
 #endif
+#if 0	
+	if (pc == 0x2f9cb8 && sfva == 0x5fa000 && curpcb->pcb_nsaved == 1)
+	{
+	  // ONLY FIXES THE FIRST PROCESS....
+	  printf("HACK: curpcb->pcb_nsaved = 0\n");
+	  curpcb->pcb_nsaved = 0;
+	}
+#endif	
 	}
 #endif
 	
@@ -1682,6 +1690,15 @@ text_access_fault(struct trapframe64 *tf, unsigned int type, vaddr_t pc,
 	u_quad_t sticks;
 	ksiginfo_t ksi;
 
+#if 1	
+	printf("%ld: text_access_fault(%p, %x, %p, %lx\n",
+		 (long)(curproc?curproc->p_pid:-1), tf, type,
+	       (void *)pc, sfsr);
+#ifdef DEBUG	
+	print_trapframe(tf);
+#endif
+#endif
+	
 #ifdef DEBUG
 	if (tf->tf_pc == tf->tf_npc) {
 		printf("text_access_fault: tpc %p == tnpc %p\n",
